@@ -86,6 +86,7 @@ static int      zenity_progress_percentage;
 static gboolean zenity_progress_pulsate;
 static gboolean zenity_progress_auto_close;
 static gboolean zenity_progress_auto_kill;
+static gboolean zenity_progress_no_cancel;
 
 /* Question Dialog Options */
 static gboolean zenity_question_active;
@@ -107,6 +108,11 @@ static gint zenity_scale_step;
 static gboolean zenity_scale_print_partial;
 static gboolean zenity_scale_hide_value;
 
+/* Color Selection Dialog Options */
+static gboolean zenity_colorsel_active;
+static gchar   *zenity_colorsel_color;
+static gboolean zenity_colorsel_show_palette;
+
 /* Miscelaneus Options */
 static gboolean zenity_misc_about;
 static gboolean zenity_misc_version;
@@ -607,6 +613,16 @@ static GOptionEntry progress_options[] = {
     N_("Kill parent process if cancel button is pressed"),
     NULL
   },
+  {
+   "no-cancel",
+   '\0',
+   0,
+   G_OPTION_ARG_NONE,
+   &zenity_progress_no_cancel,
+   /* xgettext: no-c-format */
+   N_("Hide cancel button"),
+   NULL
+  },
   { 
     NULL 
   }
@@ -807,6 +823,39 @@ static GOptionEntry scale_options[] = {
   }
 };
 
+static GOptionEntry color_selection_options[] = {
+  {
+    "color-selection",
+    '\0',
+    G_OPTION_FLAG_IN_MAIN,
+    G_OPTION_ARG_NONE,
+    &zenity_colorsel_active,
+    N_("Display color selection dialog"),
+    NULL
+  },
+  {
+    "color",
+    '\0',
+    0,
+    G_OPTION_ARG_STRING,
+    &zenity_colorsel_color,
+    N_("Set the color"),
+    N_("VALUE")
+  },
+  {
+    "show-palette",
+    '\0',
+    0,
+    G_OPTION_ARG_NONE,
+    &zenity_colorsel_show_palette,
+    N_("Show the palette"),
+    NULL
+  },
+  {
+    NULL
+  }
+};
+
 static GOptionEntry miscellaneous_options[] = {
   {
     "about",
@@ -851,6 +900,7 @@ zenity_option_init (void) {
   results->text_data = g_new0 (ZenityTextData, 1);
   results->tree_data = g_new0 (ZenityTreeData, 1);
   results->notification_data = g_new0 (ZenityNotificationData, 1);
+  results->color_data = g_new0 (ZenityColorData, 1);
 }
 
 void
@@ -886,6 +936,9 @@ zenity_option_free (void) {
   if (zenity_question_cancel_button)
     g_free (zenity_question_cancel_button);
 
+  if (zenity_colorsel_color)
+    g_free (zenity_colorsel_color);
+
   g_option_context_free (ctx);
 }
 
@@ -1050,7 +1103,7 @@ zenity_progress_pre_callback (GOptionContext *context,
   zenity_progress_pulsate = FALSE;
   zenity_progress_auto_close = FALSE;
   zenity_progress_auto_kill = FALSE;
-
+  zenity_progress_no_cancel = FALSE;
   return TRUE;
 }
 
@@ -1104,6 +1157,19 @@ zenity_scale_pre_callback (GOptionContext *context,
   return TRUE;
 }
 
+static gboolean
+zenity_color_pre_callback (GOptionContext *context,
+	                   GOptionGroup   *group,
+		           gpointer	   data,
+		           GError        **error)
+{
+  zenity_colorsel_active = FALSE;
+  zenity_colorsel_color = NULL;
+  zenity_colorsel_show_palette = FALSE;
+
+  return TRUE;
+}
+
 static gboolean
 zenity_misc_pre_callback (GOptionContext *context,
 		          GOptionGroup   *group,
@@ -1370,6 +1436,7 @@ zenity_progress_post_callback (GOptionContext *context,
     results->progress_data->autoclose = zenity_progress_auto_close;
     results->progress_data->autokill = zenity_progress_auto_kill;
     results->progress_data->percentage = zenity_progress_percentage;
+    results->progress_data->no_cancel = zenity_progress_no_cancel;
   } else {
     if (zenity_progress_pulsate)
       zenity_option_error (zenity_option_get_name (progress_options, &zenity_progress_pulsate),
@@ -1386,6 +1453,9 @@ zenity_progress_post_callback (GOptionContext *context,
     if (zenity_progress_auto_kill)
       zenity_option_error (zenity_option_get_name (progress_options, &zenity_progress_auto_kill),
                            ERROR_SUPPORT);
+    if (zenity_progress_no_cancel)
+      zenity_option_error (zenity_option_get_name (progress_options, &zenity_progress_no_cancel),
+			   ERROR_SUPPORT);
   }
     
   return TRUE;
@@ -1465,6 +1535,30 @@ zenity_scale_post_callback (GOptionContext *context,
   return TRUE;
 }
 
+static gboolean
+zenity_color_post_callback (GOptionContext *context,
+		            GOptionGroup   *group,
+		            gpointer	    data,
+		            GError        **error)
+{
+  zenity_option_set_dialog_mode (zenity_colorsel_active, MODE_COLOR);
+
+  if (results->mode == MODE_COLOR) {
+    results->color_data->color = zenity_colorsel_color;
+    results->color_data->show_palette = zenity_colorsel_show_palette;
+  } else {
+    if (zenity_colorsel_color)
+      zenity_option_error (zenity_option_get_name(color_selection_options, &zenity_colorsel_color),
+                           ERROR_SUPPORT);
+
+    if (zenity_colorsel_show_palette)
+      zenity_option_error (zenity_option_get_name(color_selection_options, &zenity_colorsel_show_palette),
+                           ERROR_SUPPORT);
+  }
+
+  return TRUE;
+}
+
 static gboolean
 zenity_misc_post_callback (GOptionContext *context,
 		           GOptionGroup   *group,
@@ -1628,6 +1722,17 @@ zenity_create_context (void)
   g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
   g_option_context_add_group(tmp_ctx, a_group);
   
+  /* Adds color selection option entries */
+  a_group = g_option_group_new("color-selection",
+                               N_("Color selection options"),
+                               N_("Show color selection options"), NULL, NULL);
+  g_option_group_add_entries(a_group, color_selection_options);
+  g_option_group_set_parse_hooks (a_group,
+                    zenity_color_pre_callback, zenity_color_post_callback);
+  g_option_group_set_error_hook (a_group, zenity_option_error_callback);
+  g_option_group_set_translation_domain (a_group, GETTEXT_PACKAGE);
+  g_option_context_add_group(tmp_ctx, a_group);
+
   /* Adds misc option entries */
   a_group = g_option_group_new("misc", 
                                N_("Miscellaneous options"), 
