@@ -29,6 +29,7 @@ typedef struct {
   gint   width;
   gint   height;
   gint   exit_code;
+  gint   timeout_delay;
 } ZenityData;
 
 typedef enum {
@@ -36,7 +37,8 @@ typedef enum {
   ZENITY_CANCEL,
   ZENITY_ESC,
   ZENITY_ERROR,
-  ZENITY_EXTRA
+  ZENITY_EXTRA,
+  ZENITY_TIMEOUT
 } ZenityExitCode;
 
 typedef struct {
@@ -58,6 +60,8 @@ typedef struct {
   gchar   *dialog_text;
   MsgMode  mode;
   gboolean no_wrap;
+  gchar   *ok_label;
+  gchar   *cancel_label;
 } ZenityMsgData;
 
 typedef struct {
@@ -77,6 +81,7 @@ typedef struct {
   gboolean save;
   gboolean confirm_overwrite;
   gchar   *separator;
+  gchar  **filter;
 } ZenityFileData;
 
 typedef struct {
@@ -93,6 +98,7 @@ typedef struct {
   gboolean autoclose;
   gboolean autokill;
   gdouble  percentage;
+  gboolean no_cancel;
 } ZenityProgressData;
 
 typedef struct {
@@ -106,6 +112,7 @@ typedef struct {
   GSList       *columns;
   gboolean      checkbox;
   gboolean      radiobox;
+  gboolean      hide_header;
   gchar        *separator;
   gboolean      multi;
   gboolean      editable;
@@ -119,6 +126,11 @@ typedef struct {
   gboolean listen;
 } ZenityNotificationData;
 
+typedef struct {
+  gchar   *color;
+  gboolean show_palette;
+} ZenityColorData;
+
 void    zenity_calendar         (ZenityData             *data,
                                 ZenityCalendarData      *calendar_data);
 void    zenity_msg              (ZenityData             *data,
@@ -135,6 +147,8 @@ void    zenity_tree             (ZenityData             *data,
                                  ZenityTreeData         *tree_data);
 void	zenity_notification	(ZenityData		*data,
 				 ZenityNotificationData	*notification_data);
+void    zenity_colorselection   (ZenityData             *data,
+                                 ZenityColorData        *notification_data);
 void	zenity_scale		(ZenityData		*data,
 				 ZenityScaleData	*scale_data);
 void    zenity_about            (ZenityData             *data);
